@@ -49,7 +49,9 @@ tasseledCap <- function(img, sat, ...) {
         x %*% cof 
     }
     
-    calc(img, fun = tct, forcefun = TRUE, ...)
+	out <- .paraRasterFun(img, rasterFun = calc, args = list(fun = tct, forcefun = TRUE), wrArgs = list(...))
+	out <- .updateLayerNames(out, colnames(.TCcoefs[[sat]]))
+	out
 }
 
 
