@@ -37,10 +37,10 @@
 #' ## Validation
 #' ## Before filtering
 #' val0 <- validateMap(sc$map, valData = val, responseCol = "class", 
-#' 							classMapping = sc$classMapping)
+#'                             classMapping = sc$classMapping)
 #' ## After filtering
 #' val1 <- validateMap(polishedMap, valData = val, responseCol = "class",
-#' 							 classMapping = sc$classMapping)
+#'                              classMapping = sc$classMapping)
 #' }
 validateMap <- function(map, valData, responseCol, nSamples = 500,  mode = "classification", classMapping = NULL){
     
@@ -52,7 +52,7 @@ validateMap <- function(map, valData, responseCol, nSamples = 500,  mode = "clas
         if(!is.null(classMapping)) {
             valiSet[[1]][,"prediction"] <- classMapping[match(valiSet[[1]][,"prediction"], classMapping$classID),"class"]
         } 
-        performance <- confusionMatrix(valiSet[[1]][,"prediction"], reference = valiSet[[1]][,"reference"])
+        performance <- confusionMatrix(as.factor(valiSet[[1]][,"prediction"]), reference = as.factor(valiSet[[1]][,"reference"]))
     } else {
         performance <- postResample(pred = valiSet[[1]][,"prediction"], obs = valiSet[[1]][,"reference"])    
     }
